You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@marmotta.apache.org by ss...@apache.org on 2013/02/22 16:54:35 UTC

[3/5] renamed some classes and properties from kiwi/lmf to marmot

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/jndi/MarmottaInitialContextFactoryBuilder.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/jndi/MarmottaInitialContextFactoryBuilder.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/jndi/MarmottaInitialContextFactoryBuilder.java
new file mode 100644
index 0000000..0860761
--- /dev/null
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/jndi/MarmottaInitialContextFactoryBuilder.java
@@ -0,0 +1,50 @@
+/**
+ * Copyright (C) 2013 Salzburg Research.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.marmotta.platform.core.jndi;
+
+import javax.naming.Context;
+import javax.naming.NamingException;
+import javax.naming.spi.InitialContextFactory;
+import javax.naming.spi.InitialContextFactoryBuilder;
+import java.util.Hashtable;
+
+/**
+ * Add file description here!
+ * <p/>
+ * Author: Sebastian Schaffert
+ */
+public class MarmottaInitialContextFactoryBuilder implements InitialContextFactoryBuilder {
+
+    public MarmottaInitialContextFactoryBuilder() {
+    }
+
+    @Override
+    public InitialContextFactory createInitialContextFactory(Hashtable<?, ?> hashtable) throws NamingException {
+        // check if we are inside the LMF or outside; inside the LMF we return our own context factory,
+        // outside the system default
+        try {
+            return (InitialContextFactory) Thread.currentThread().getContextClassLoader().loadClass(MarmottaContextFactory.class.getName()).getMethod("getInstance").invoke(null);
+        } catch (Exception e) {
+            String factoryName = Context.INITIAL_CONTEXT_FACTORY;
+
+            try {
+                return (InitialContextFactory) Thread.currentThread().getContextClassLoader().loadClass(factoryName).newInstance();
+            } catch (Exception e1) {
+                throw new NamingException("default context factory "+factoryName+" could not be initialised");
+            }
+        }
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/jndi/MarmottaJndiListener.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/jndi/MarmottaJndiListener.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/jndi/MarmottaJndiListener.java
new file mode 100644
index 0000000..8f02ee7
--- /dev/null
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/jndi/MarmottaJndiListener.java
@@ -0,0 +1,64 @@
+/**
+ * Copyright (C) 2013 Salzburg Research.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.marmotta.platform.core.jndi;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import javax.naming.NamingException;
+import javax.naming.spi.NamingManager;
+import javax.servlet.ServletContextEvent;
+import javax.servlet.ServletContextListener;
+
+/**
+ * Add file description here!
+ * <p/>
+ * Author: Sebastian Schaffert
+ */
+public class MarmottaJndiListener implements ServletContextListener {
+
+    private static Logger log = LoggerFactory.getLogger(MarmottaJndiListener.class);
+
+    /**
+     * * Notification that the web application initialization
+     * * process is starting.
+     * * All ServletContextListeners are notified of context
+     * * initialization before any filter or servlet in the web
+     * * application is initialized.
+     */
+    @Override
+    public void contextInitialized(ServletContextEvent sce) {
+        log.info("JNDI: registering Apache Marmotta JNDI implementation ...");
+        try {
+            NamingManager.setInitialContextFactoryBuilder(new MarmottaInitialContextFactoryBuilder());
+        } catch (NamingException e) {
+
+        } catch (IllegalStateException e) {
+            log.info("JNDI: a context factory of type is already installed");
+        }
+    }
+
+    /**
+     * * Notification that the servlet context is about to be shut down.
+     * * All servlets and filters have been destroy()ed before any
+     * * ServletContextListeners are notified of context
+     * * destruction.
+     */
+    @Override
+    public void contextDestroyed(ServletContextEvent sce) {
+        //To change body of implemented methods use File | Settings | File Templates.
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/filter/LMFLocalFilter.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/filter/LMFLocalFilter.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/filter/LMFLocalFilter.java
deleted file mode 100644
index 1f3724b..0000000
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/filter/LMFLocalFilter.java
+++ /dev/null
@@ -1,75 +0,0 @@
-/**
- * Copyright (C) 2013 Salzburg Research.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-package org.apache.marmotta.platform.core.model.filter;
-
-import org.apache.marmotta.platform.core.api.config.ConfigurationService;
-import org.apache.marmotta.platform.core.util.KiWiContext;
-
-import org.apache.marmotta.commons.sesame.filter.resource.ResourceFilter;
-import org.openrdf.model.BNode;
-import org.openrdf.model.Resource;
-import org.openrdf.model.URI;
-
-/**
- * Accept only resources that are considered "local", i.e. either have the same URI prefix as the system,
- * start with file:, start with urn:, or are blank nodes.
- * <p/>
- * Author: Sebastian Schaffert
- */
-public class LMFLocalFilter implements ResourceFilter {
-
-    private ConfigurationService configurationService;
-
-    public LMFLocalFilter() {
-        configurationService = KiWiContext.getInstance(ConfigurationService.class);
-    }
-
-
-    private static LMFLocalFilter instance = null;
-
-    public static LMFLocalFilter getInstance() {
-        if(instance == null) {
-            instance = new LMFLocalFilter();
-        }
-        return instance;
-    }
-
-
-    /**
-     * Return false in case the filter does not accept the resource passed as argument, true otherwise.
-     *
-     *
-     * @param resource
-     * @return
-     */
-    @Override
-    public boolean accept(Resource resource) {
-        if(resource instanceof BNode) {
-            return true;
-        }
-
-        URI uri = (URI)resource;
-
-        if(uri.stringValue().startsWith("file:") || uri.stringValue().startsWith("urn:")) {
-            return true;
-        }
-
-        return uri.stringValue().startsWith(configurationService.getBaseUri());
-
-
-    }
-
-}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/filter/MarmottaLocalFilter.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/filter/MarmottaLocalFilter.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/filter/MarmottaLocalFilter.java
new file mode 100644
index 0000000..ab9c5cd
--- /dev/null
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/filter/MarmottaLocalFilter.java
@@ -0,0 +1,75 @@
+/**
+ * Copyright (C) 2013 Salzburg Research.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.marmotta.platform.core.model.filter;
+
+import org.apache.marmotta.platform.core.api.config.ConfigurationService;
+import org.apache.marmotta.platform.core.util.CDIContext;
+
+import org.apache.marmotta.commons.sesame.filter.resource.ResourceFilter;
+import org.openrdf.model.BNode;
+import org.openrdf.model.Resource;
+import org.openrdf.model.URI;
+
+/**
+ * Accept only resources that are considered "local", i.e. either have the same URI prefix as the system,
+ * start with file:, start with urn:, or are blank nodes.
+ * <p/>
+ * Author: Sebastian Schaffert
+ */
+public class MarmottaLocalFilter implements ResourceFilter {
+
+    private ConfigurationService configurationService;
+
+    public MarmottaLocalFilter() {
+        configurationService = CDIContext.getInstance(ConfigurationService.class);
+    }
+
+
+    private static MarmottaLocalFilter instance = null;
+
+    public static MarmottaLocalFilter getInstance() {
+        if(instance == null) {
+            instance = new MarmottaLocalFilter();
+        }
+        return instance;
+    }
+
+
+    /**
+     * Return false in case the filter does not accept the resource passed as argument, true otherwise.
+     *
+     *
+     * @param resource
+     * @return
+     */
+    @Override
+    public boolean accept(Resource resource) {
+        if(resource instanceof BNode) {
+            return true;
+        }
+
+        URI uri = (URI)resource;
+
+        if(uri.stringValue().startsWith("file:") || uri.stringValue().startsWith("urn:")) {
+            return true;
+        }
+
+        return uri.stringValue().startsWith(configurationService.getBaseUri());
+
+
+    }
+
+}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/user/KiWiUser.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/user/KiWiUser.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/user/KiWiUser.java
deleted file mode 100644
index 317c557..0000000
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/user/KiWiUser.java
+++ /dev/null
@@ -1,65 +0,0 @@
-/**
- * Copyright (C) 2013 Salzburg Research.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-package org.apache.marmotta.platform.core.model.user;
-
-import org.apache.marmotta.commons.sesame.facading.annotations.RDF;
-import org.apache.marmotta.commons.sesame.facading.annotations.RDFType;
-import org.apache.marmotta.commons.sesame.facading.model.Facade;
-import org.apache.marmotta.commons.sesame.model.Namespaces;
-import org.openrdf.model.URI;
-
-import java.util.Set;
-
-
-/**
- * User: Stephanie Stroka
- * Date: 18.05.2011
- * Time: 11:29:17
- */
-@RDFType(Namespaces.NS_FOAF + "Person")
-public interface KiWiUser extends Facade {
-
-    @RDF(Namespaces.NS_FOAF + "nick")
-    public String getNick();
-    public void setNick(String nick);
-
-    /**
-     * The first name of the user; mapped to the foaf:firstName RDF property
-     */
-    @RDF(Namespaces.NS_FOAF + "firstName")
-    public String getFirstName();
-    public void setFirstName(String firstName);
-
-    /**
-     * The last name of the user; mapped to the foaf:lastName RDF property
-     */
-    @RDF(Namespaces.NS_FOAF + "lastName")
-    public String getLastName();
-    public void setLastName(String lastName);
-
-    @RDF(Namespaces.NS_FOAF + "mbox")
-    public String getMbox();
-    public void setMbox(String mbox);
-
-    @RDF(Namespaces.NS_FOAF + "depiction")
-    public URI getDepiciton();
-    public void setDepiction(URI depiction);
-
-    @RDF(Namespaces.NS_FOAF + "account")
-    public Set<OnlineAccount> getOnlineAccounts();
-    public void setOnlineAccounts(Set<OnlineAccount> onlineAccounts);
-    
-}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/user/MarmottaUser.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/user/MarmottaUser.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/user/MarmottaUser.java
new file mode 100644
index 0000000..a33eb9c
--- /dev/null
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/model/user/MarmottaUser.java
@@ -0,0 +1,65 @@
+/**
+ * Copyright (C) 2013 Salzburg Research.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.marmotta.platform.core.model.user;
+
+import org.apache.marmotta.commons.sesame.facading.annotations.RDF;
+import org.apache.marmotta.commons.sesame.facading.annotations.RDFType;
+import org.apache.marmotta.commons.sesame.facading.model.Facade;
+import org.apache.marmotta.commons.sesame.model.Namespaces;
+import org.openrdf.model.URI;
+
+import java.util.Set;
+
+
+/**
+ * User: Stephanie Stroka
+ * Date: 18.05.2011
+ * Time: 11:29:17
+ */
+@RDFType(Namespaces.NS_FOAF + "Person")
+public interface MarmottaUser extends Facade {
+
+    @RDF(Namespaces.NS_FOAF + "nick")
+    public String getNick();
+    public void setNick(String nick);
+
+    /**
+     * The first name of the user; mapped to the foaf:firstName RDF property
+     */
+    @RDF(Namespaces.NS_FOAF + "firstName")
+    public String getFirstName();
+    public void setFirstName(String firstName);
+
+    /**
+     * The last name of the user; mapped to the foaf:lastName RDF property
+     */
+    @RDF(Namespaces.NS_FOAF + "lastName")
+    public String getLastName();
+    public void setLastName(String lastName);
+
+    @RDF(Namespaces.NS_FOAF + "mbox")
+    public String getMbox();
+    public void setMbox(String mbox);
+
+    @RDF(Namespaces.NS_FOAF + "depiction")
+    public URI getDepiciton();
+    public void setDepiction(URI depiction);
+
+    @RDF(Namespaces.NS_FOAF + "account")
+    public Set<OnlineAccount> getOnlineAccounts();
+    public void setOnlineAccounts(Set<OnlineAccount> onlineAccounts);
+    
+}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/qualifiers/cache/LMFCache.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/qualifiers/cache/LMFCache.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/qualifiers/cache/LMFCache.java
deleted file mode 100644
index 5ce40bb..0000000
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/qualifiers/cache/LMFCache.java
+++ /dev/null
@@ -1,41 +0,0 @@
-/**
- * Copyright (C) 2013 Salzburg Research.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-package org.apache.marmotta.platform.core.qualifiers.cache;
-
-import javax.enterprise.util.Nonbinding;
-import javax.inject.Qualifier;
-import java.lang.annotation.Retention;
-import java.lang.annotation.Target;
-
-import static java.lang.annotation.ElementType.*;
-import static java.lang.annotation.RetentionPolicy.RUNTIME;
-
-/**
- * An annotation to discriminate the injection of different caches using KiWi's CachingService
- *
- * Usage:
- * @Inject @KiWiCache("cache-name")
- * private Ehcache cache;
- *
- * <p/>
- * User: sschaffe
- */
-@Qualifier
-@Retention(RUNTIME)
-@Target({TYPE, METHOD, FIELD, PARAMETER})
-public @interface LMFCache {
-    @Nonbinding public String value();
-}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/qualifiers/cache/MarmottaCache.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/qualifiers/cache/MarmottaCache.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/qualifiers/cache/MarmottaCache.java
new file mode 100644
index 0000000..08c1910
--- /dev/null
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/qualifiers/cache/MarmottaCache.java
@@ -0,0 +1,41 @@
+/**
+ * Copyright (C) 2013 Salzburg Research.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.marmotta.platform.core.qualifiers.cache;
+
+import javax.enterprise.util.Nonbinding;
+import javax.inject.Qualifier;
+import java.lang.annotation.Retention;
+import java.lang.annotation.Target;
+
+import static java.lang.annotation.ElementType.*;
+import static java.lang.annotation.RetentionPolicy.RUNTIME;
+
+/**
+ * An annotation to discriminate the injection of different caches using KiWi's CachingService
+ *
+ * Usage:
+ * @Inject @KiWiCache("cache-name")
+ * private Ehcache cache;
+ *
+ * <p/>
+ * User: sschaffe
+ */
+@Qualifier
+@Retention(RUNTIME)
+@Target({TYPE, METHOD, FIELD, PARAMETER})
+public @interface MarmottaCache {
+    @Nonbinding public String value();
+}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/rio/RDFHtmlWriterImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/rio/RDFHtmlWriterImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/rio/RDFHtmlWriterImpl.java
index c25cab1..d10753a 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/rio/RDFHtmlWriterImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/rio/RDFHtmlWriterImpl.java
@@ -20,7 +20,7 @@ import org.apache.marmotta.platform.core.api.io.RDFHtmlWriter;
 import org.apache.marmotta.platform.core.api.io.RDFWriterPriority;
 import org.apache.marmotta.platform.core.api.prefix.PrefixService;
 import org.apache.marmotta.platform.core.services.templating.TemplatingHelper;
-import org.apache.marmotta.platform.core.util.KiWiContext;
+import org.apache.marmotta.platform.core.util.CDIContext;
 import org.apache.commons.lang.StringUtils;
 import org.apache.marmotta.commons.http.UriUtil;
 import org.apache.marmotta.kiwi.model.rdf.KiWiTriple;
@@ -83,9 +83,9 @@ public class RDFHtmlWriterImpl implements RDFHtmlWriter {
         this.writer = writer;
 
         // FIXME: usage of KiWiContext is not recommened!
-        configurationService = KiWiContext
+        configurationService = CDIContext
                 .getInstance(ConfigurationService.class);
-        prefixService = KiWiContext.getInstance(PrefixService.class);
+        prefixService = CDIContext.getInstance(PrefixService.class);
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/cache/CachingServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/cache/CachingServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/cache/CachingServiceImpl.java
index 7a215ab..27d3a15 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/cache/CachingServiceImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/cache/CachingServiceImpl.java
@@ -17,7 +17,7 @@ package org.apache.marmotta.platform.core.services.cache;
 
 import org.apache.marmotta.platform.core.api.cache.CachingService;
 import org.apache.marmotta.platform.core.events.SystemRestartingEvent;
-import org.apache.marmotta.platform.core.qualifiers.cache.LMFCache;
+import org.apache.marmotta.platform.core.qualifiers.cache.MarmottaCache;
 import net.sf.ehcache.CacheManager;
 import net.sf.ehcache.Ehcache;
 import org.slf4j.Logger;
@@ -74,9 +74,9 @@ public class CachingServiceImpl implements CachingService {
      * @return
      */
     @Override
-    @Produces @LMFCache("")
+    @Produces @MarmottaCache("")
     public Ehcache getCache(InjectionPoint injectionPoint) {
-        String cacheName = injectionPoint.getAnnotated().getAnnotation(LMFCache.class).value();
+        String cacheName = injectionPoint.getAnnotated().getAnnotation(MarmottaCache.class).value();
 
         return getCacheByName(cacheName);
     }

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/config/ConfigurationServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/content/ContentServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/content/ContentServiceImpl.java
index 742ba02..b72c8e8 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/content/ContentServiceImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/content/ContentServiceImpl.java
@@ -20,7 +20,7 @@ import org.apache.marmotta.platform.core.api.content.ContentReader;
 import org.apache.marmotta.platform.core.api.content.ContentService;
 import org.apache.marmotta.platform.core.api.content.ContentWriter;
 import org.apache.marmotta.platform.core.events.ConfigurationChangedEvent;
-import org.apache.marmotta.platform.core.exception.LMFException;
+import org.apache.marmotta.platform.core.exception.MarmottaException;
 import org.apache.marmotta.platform.core.exception.WritingNotSupportedException;
 import org.openrdf.model.Resource;
 import org.slf4j.Logger;
@@ -308,7 +308,7 @@ public class ContentServiceImpl implements ContentService {
     }
 
     @Override
-    public boolean deleteContent(Resource resource) throws LMFException {
+    public boolean deleteContent(Resource resource) throws MarmottaException {
         // iterate over all possible writers; if the pattern matches, try to store the content and return
         for(Pattern p : writerMap.keySet()) {
             if(p.matcher(resource.toString()).matches()) {

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/exporter/ExporterServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/exporter/ExporterServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/exporter/ExporterServiceImpl.java
index 9f4495c..df598a2 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/exporter/ExporterServiceImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/exporter/ExporterServiceImpl.java
@@ -17,7 +17,7 @@ package org.apache.marmotta.platform.core.services.exporter;
 
 import com.google.common.collect.ImmutableSet;
 import org.apache.marmotta.platform.core.api.exporter.ExportService;
-import org.apache.marmotta.platform.core.api.io.LMFIOService;
+import org.apache.marmotta.platform.core.api.io.MarmottaIOService;
 import org.apache.marmotta.platform.core.api.triplestore.SesameService;
 import org.apache.marmotta.platform.core.exception.io.UnsupportedExporterException;
 import org.openrdf.model.URI;
@@ -50,7 +50,7 @@ public class ExporterServiceImpl implements ExportService {
     private Logger log;
 
     @Inject
-    private LMFIOService ioService;
+    private MarmottaIOService ioService;
 
 
     @Inject

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/http/HttpClientServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/http/HttpClientServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/http/HttpClientServiceImpl.java
index 82784e2..d6fb8c0 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/http/HttpClientServiceImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/http/HttpClientServiceImpl.java
@@ -22,7 +22,7 @@ import org.apache.marmotta.platform.core.api.statistics.StatisticsService;
 import org.apache.marmotta.platform.core.api.task.Task;
 import org.apache.marmotta.platform.core.api.task.TaskManagerService;
 import org.apache.marmotta.platform.core.events.ConfigurationChangedEvent;
-import org.apache.marmotta.platform.core.qualifiers.cache.LMFCache;
+import org.apache.marmotta.platform.core.qualifiers.cache.MarmottaCache;
 import org.apache.marmotta.platform.core.services.http.response.LastModifiedResponseHandler;
 import org.apache.marmotta.platform.core.services.http.response.StatusCodeResponseHandler;
 import org.apache.marmotta.platform.core.services.http.response.StringBodyResponseHandler;
@@ -99,7 +99,7 @@ public class HttpClientServiceImpl implements HttpClientService {
     private StatisticsService            statisticsService;
 
     @Inject
-    @LMFCache("http-client-cache")
+    @MarmottaCache("http-client-cache")
     private Instance<Ehcache>            ehcache;
 
     private HttpClient                   httpClient;

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/ImportServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/ImportServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/ImportServiceImpl.java
index 9add952..70ba85f 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/ImportServiceImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/ImportServiceImpl.java
@@ -17,7 +17,7 @@ package org.apache.marmotta.platform.core.services.importer;
 
 import org.apache.marmotta.platform.core.api.importer.ImportService;
 import org.apache.marmotta.platform.core.api.importer.Importer;
-import org.apache.marmotta.platform.core.exception.io.LMFImportException;
+import org.apache.marmotta.platform.core.exception.io.MarmottaImportException;
 import org.openrdf.model.Resource;
 import org.openrdf.model.URI;
 import org.slf4j.Logger;
@@ -68,22 +68,22 @@ public class ImportServiceImpl implements ImportService{
 	}
 
 	@Override
-	public int importData(URL url, String format, Resource user, URI context) throws LMFImportException {
+	public int importData(URL url, String format, Resource user, URI context) throws MarmottaImportException {
 		return getImporterInstance(format).importData(url,format,user,context);
 	}
 
 	@Override
-	public int importData(InputStream is, String format, Resource user, URI context) throws LMFImportException {
+	public int importData(InputStream is, String format, Resource user, URI context) throws MarmottaImportException {
 		return getImporterInstance(format).importData(is,format,user,context);
 	}
 
 	@Override
-	public int importData(Reader reader, String format, Resource user, URI context) throws LMFImportException {
+	public int importData(Reader reader, String format, Resource user, URI context) throws MarmottaImportException {
 		return getImporterInstance(format).importData(reader,format,user,context);
 	}
 
-	private Importer getImporterInstance(String type) throws LMFImportException {
-		if(!importerMap.containsKey(type)) throw new LMFImportException("no importer defined for type "+type);
+	private Importer getImporterInstance(String type) throws MarmottaImportException {
+		if(!importerMap.containsKey(type)) throw new MarmottaImportException("no importer defined for type "+type);
 		return importerMap.get(type);
 	}
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/rdf/RDFImporterImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/rdf/RDFImporterImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/rdf/RDFImporterImpl.java
index 04c2bdf..2ddfd19 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/rdf/RDFImporterImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/importer/rdf/RDFImporterImpl.java
@@ -20,7 +20,7 @@ import org.apache.marmotta.platform.core.api.importer.Importer;
 import org.apache.marmotta.platform.core.api.task.Task;
 import org.apache.marmotta.platform.core.api.task.TaskManagerService;
 import org.apache.marmotta.platform.core.api.triplestore.SesameService;
-import org.apache.marmotta.platform.core.exception.io.LMFImportException;
+import org.apache.marmotta.platform.core.exception.io.MarmottaImportException;
 import org.openrdf.model.Resource;
 import org.openrdf.model.URI;
 import org.openrdf.repository.RepositoryConnection;
@@ -117,7 +117,7 @@ public class RDFImporterImpl implements Importer {
      */
     @Override
     //@RaiseEvent("ontologyChanged")
-    public int importData(URL url, String format, Resource user, URI context) throws LMFImportException {
+    public int importData(URL url, String format, Resource user, URI context) throws MarmottaImportException {
         try {
             return importData(url.openStream(), format, user,context, url.toString());
         } catch (IOException ex) {
@@ -140,7 +140,7 @@ public class RDFImporterImpl implements Importer {
      */
     @Override
     //@RaiseEvent("ontologyChanged")
-    public int importData(InputStream is, String format, Resource user, URI context) throws LMFImportException {
+    public int importData(InputStream is, String format, Resource user, URI context) throws MarmottaImportException {
         String baseUri = configurationService.getBaseUri() + "resource/";
         return importData(is,format,user,context,baseUri);
     }
@@ -157,7 +157,7 @@ public class RDFImporterImpl implements Importer {
      * @param user the user to use as author of all imported data
      */
     //@RaiseEvent("ontologyChanged")
-    private int importData(InputStream is, String format, Resource user, URI context, String baseUri) throws LMFImportException {
+    private int importData(InputStream is, String format, Resource user, URI context, String baseUri) throws MarmottaImportException {
 
         // TODO: need to figure out format automatically!
         RDFFormat f = getFormat(format);
@@ -201,7 +201,7 @@ public class RDFImporterImpl implements Importer {
             }
         } catch (Exception ex) {
             log.error("error while importing Sesame data:", ex);
-            throw new LMFImportException(ex);
+            throw new MarmottaImportException(ex);
         } finally {
             taskManagerService.endTask(task);
         }
@@ -221,7 +221,7 @@ public class RDFImporterImpl implements Importer {
      * @param user the user to use as author of all imported data
      */
     @Override
-    public int importData(Reader reader, String format, Resource user, URI context) throws LMFImportException {
+    public int importData(Reader reader, String format, Resource user, URI context) throws MarmottaImportException {
 
         // TODO: need to figure out format automatically!
         RDFFormat f = getFormat(format);
@@ -267,7 +267,7 @@ public class RDFImporterImpl implements Importer {
             }
         } catch (Exception ex) {
             log.error("error while importing Sesame data:", ex);
-            throw new LMFImportException(ex);
+            throw new MarmottaImportException(ex);
         } finally {
             taskManagerService.endTask(task);
         }

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/io/LMFIOServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/io/LMFIOServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/io/LMFIOServiceImpl.java
deleted file mode 100644
index c98abff..0000000
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/io/LMFIOServiceImpl.java
+++ /dev/null
@@ -1,109 +0,0 @@
-/**
- * Copyright (C) 2013 Salzburg Research.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-package org.apache.marmotta.platform.core.services.io;
-
-import org.apache.marmotta.platform.core.api.io.LMFIOService;
-import org.openrdf.rio.RDFFormat;
-import org.openrdf.rio.RDFParserRegistry;
-import org.openrdf.rio.RDFWriterRegistry;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
-import javax.annotation.PostConstruct;
-import javax.enterprise.context.ApplicationScoped;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.List;
-
-/**
- * User: Thomas Kurz
- * Date: 18.02.11
- * Time: 10:41
- */
-@ApplicationScoped
-public class LMFIOServiceImpl implements LMFIOService {
-
-    private Logger log = LoggerFactory.getLogger(this.getClass());
-
-    private RDFParserRegistry parserRegistry;
-    private RDFWriterRegistry writerRegistry;
-
-    private List<String> acceptTypes;
-    private List<String> producedTypes;
-
-    @PostConstruct
-    public void initialise() {
-        log.info("initialising Apache Marmotta I/O service ...");
-
-        parserRegistry = RDFParserRegistry.getInstance();
-
-        acceptTypes = new ArrayList<String>();
-        for(RDFFormat format : parserRegistry.getKeys()) {
-            acceptTypes.addAll(format.getMIMETypes());
-        }
-        log.info(" - available parsers: {}", Arrays.toString(acceptTypes.toArray()));
-
-        writerRegistry = RDFWriterRegistry.getInstance();
-
-        producedTypes = new ArrayList<String>();
-        for(RDFFormat format : writerRegistry.getKeys()) {
-            producedTypes.addAll(format.getMIMETypes());
-        }
-        log.info(" - available writers: {}", Arrays.toString(producedTypes.toArray()));
-
-
-
-    }
-
-
-	/**
-	 * returns a list of all mimetypes which can be parsed by implemented parsers
-	 * @return
-	 */
-	@Override
-	public List<String> getAcceptTypes() {
-		return acceptTypes;
-	}
-
-	/**
-	 * returns a list of all mimetypes which can be produced by implemented serializers
-	 * @return
-	 */
-	@Override
-	public List<String> getProducedTypes() {
-		return producedTypes;
-	}
-
-	/**
-	 * returns a serializer for a given mimetype; null if no serializer defined
-	 * @param mimetype
-	 * @return
-	 */
-	@Override
-	public RDFFormat getSerializer(String mimetype) {
-		return writerRegistry.getFileFormatForMIMEType(mimetype);
-	}
-
-	/**
-	 * returns a parser for a given mimetype; null if no parser defined
-	 * @param mimetype
-	 * @return
-	 */
-	@Override
-	public RDFFormat getParser(String mimetype) {
-		return parserRegistry.getFileFormatForMIMEType(mimetype);
-	}
-}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/io/MarmottaIOServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/io/MarmottaIOServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/io/MarmottaIOServiceImpl.java
new file mode 100644
index 0000000..a25a0b0
--- /dev/null
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/io/MarmottaIOServiceImpl.java
@@ -0,0 +1,109 @@
+/**
+ * Copyright (C) 2013 Salzburg Research.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.marmotta.platform.core.services.io;
+
+import org.apache.marmotta.platform.core.api.io.MarmottaIOService;
+import org.openrdf.rio.RDFFormat;
+import org.openrdf.rio.RDFParserRegistry;
+import org.openrdf.rio.RDFWriterRegistry;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import javax.annotation.PostConstruct;
+import javax.enterprise.context.ApplicationScoped;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.List;
+
+/**
+ * User: Thomas Kurz
+ * Date: 18.02.11
+ * Time: 10:41
+ */
+@ApplicationScoped
+public class MarmottaIOServiceImpl implements MarmottaIOService {
+
+    private Logger log = LoggerFactory.getLogger(this.getClass());
+
+    private RDFParserRegistry parserRegistry;
+    private RDFWriterRegistry writerRegistry;
+
+    private List<String> acceptTypes;
+    private List<String> producedTypes;
+
+    @PostConstruct
+    public void initialise() {
+        log.info("initialising Apache Marmotta I/O service ...");
+
+        parserRegistry = RDFParserRegistry.getInstance();
+
+        acceptTypes = new ArrayList<String>();
+        for(RDFFormat format : parserRegistry.getKeys()) {
+            acceptTypes.addAll(format.getMIMETypes());
+        }
+        log.info(" - available parsers: {}", Arrays.toString(acceptTypes.toArray()));
+
+        writerRegistry = RDFWriterRegistry.getInstance();
+
+        producedTypes = new ArrayList<String>();
+        for(RDFFormat format : writerRegistry.getKeys()) {
+            producedTypes.addAll(format.getMIMETypes());
+        }
+        log.info(" - available writers: {}", Arrays.toString(producedTypes.toArray()));
+
+
+
+    }
+
+
+	/**
+	 * returns a list of all mimetypes which can be parsed by implemented parsers
+	 * @return
+	 */
+	@Override
+	public List<String> getAcceptTypes() {
+		return acceptTypes;
+	}
+
+	/**
+	 * returns a list of all mimetypes which can be produced by implemented serializers
+	 * @return
+	 */
+	@Override
+	public List<String> getProducedTypes() {
+		return producedTypes;
+	}
+
+	/**
+	 * returns a serializer for a given mimetype; null if no serializer defined
+	 * @param mimetype
+	 * @return
+	 */
+	@Override
+	public RDFFormat getSerializer(String mimetype) {
+		return writerRegistry.getFileFormatForMIMEType(mimetype);
+	}
+
+	/**
+	 * returns a parser for a given mimetype; null if no parser defined
+	 * @param mimetype
+	 * @return
+	 */
+	@Override
+	public RDFFormat getParser(String mimetype) {
+		return parserRegistry.getFileFormatForMIMEType(mimetype);
+	}
+}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/logging/LMFLogbackPropertyDefiner.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/logging/LMFLogbackPropertyDefiner.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/logging/LMFLogbackPropertyDefiner.java
index 8d5764f..8d60234 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/logging/LMFLogbackPropertyDefiner.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/logging/LMFLogbackPropertyDefiner.java
@@ -19,7 +19,7 @@ import ch.qos.logback.core.Context;
 import ch.qos.logback.core.spi.PropertyDefiner;
 import ch.qos.logback.core.status.Status;
 import org.apache.marmotta.platform.core.api.config.ConfigurationService;
-import org.apache.marmotta.platform.core.util.KiWiContext;
+import org.apache.marmotta.platform.core.util.CDIContext;
 
 /**
  * An abstract class with access to the LMF Configuration Service to get access to LMF runtime configuration.
@@ -36,7 +36,7 @@ public class LMFLogbackPropertyDefiner implements PropertyDefiner {
     protected String key;
 
     public LMFLogbackPropertyDefiner() {
-        configurationService = KiWiContext.getInstance(ConfigurationService.class);
+        configurationService = CDIContext.getInstance(ConfigurationService.class);
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/modules/LMFResourceServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/modules/LMFResourceServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/modules/LMFResourceServiceImpl.java
deleted file mode 100644
index be04cfd..0000000
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/modules/LMFResourceServiceImpl.java
+++ /dev/null
@@ -1,252 +0,0 @@
-/**
- * Copyright (C) 2013 Salzburg Research.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-package org.apache.marmotta.platform.core.services.modules;
-
-import com.google.common.io.ByteStreams;
-import eu.medsea.mimeutil.MimeType;
-import eu.medsea.mimeutil.MimeUtil2;
-import org.apache.marmotta.platform.core.api.config.ConfigurationService;
-import org.apache.marmotta.platform.core.api.modules.LMFResourceService;
-import org.apache.marmotta.platform.core.api.modules.ModuleService;
-import org.apache.marmotta.platform.core.api.modules.ResourceEntry;
-import org.apache.marmotta.platform.core.events.SystemStartupEvent;
-import org.apache.marmotta.platform.core.model.module.ModuleConfiguration;
-import org.apache.marmotta.platform.core.qualifiers.cache.LMFCache;
-import net.sf.ehcache.Ehcache;
-import net.sf.ehcache.Element;
-import org.slf4j.Logger;
-
-import javax.annotation.PostConstruct;
-import javax.enterprise.context.ApplicationScoped;
-import javax.enterprise.event.Observes;
-import javax.inject.Inject;
-
-import java.io.IOException;
-import java.net.URL;
-import java.util.Collection;
-import java.util.HashMap;
-import java.util.Map;
-
-/**
- * A service for resolving and accessing resources contained in the Apache Marmotta modules. The resource service takes care
- * of retrieving, caching and refreshing resources from the appropriate locations.
- * <p/>
- * Note that the resource service is not to be confused with the RDF resources maintained by the server. It is
- * purely meant to retrieve static non-Java resources contained in the modules and web application.
- *
- * User: sschaffe
- */
-@ApplicationScoped
-public class LMFResourceServiceImpl implements LMFResourceService {
-
-    @Inject
-    private Logger log;
-
-    @Inject
-    private ConfigurationService configurationService;
-
-
-    @Inject
-    private ModuleService moduleService;
-
-
-    @Inject @LMFCache("resource-cache")
-    private Ehcache resourceCache;
-
-    /**
-     * Used for detecting the mime type of resources contained in KiWi modules
-     */
-    private MimeUtil2 mimeUtil;
-
-
-    private Map<String,String> resourceMap;
-
-
-    @PostConstruct
-    public void initialise() {
-        // find all kiwi-module.properties and check whether they contain a baseurl property to map module web
-        // resources to a certain path prefix; if yes, store the prefix and jar URL in the map for lookup and
-        // resource resolving by the filter
-        this.resourceMap = new HashMap<String, String>();
-
-
-        for(String module : moduleService.listModules()) {
-            ModuleConfiguration config = moduleService.getModuleConfiguration(module);
-
-            if(config.getConfiguration().containsKey("baseurl")) {
-                String path = config.getConfiguration().getString("baseurl");
-                resourceMap.put(path.startsWith("/")?path:"/"+path,moduleService.getModuleJar(module).toString());
-            }
-        }
-
-
-
-        // detect the mime type of resources
-        this.mimeUtil = new MimeUtil2();
-        this.mimeUtil.registerMimeDetector("eu.medsea.mimeutil.detector.ExtensionMimeDetector");
-    }
-
-
-    /**
-     * Makes sure the service is initialised on system startup
-     *
-     * @param event
-     */
-    public void systemStartup(@Observes SystemStartupEvent event) {
-
-    }
-
-
-    /**
-     * Return the resource identified by the relative URL passed as argument. The passed argument is relative
-     * to the web application root of this web application.
-     *
-     * @param relativeURL a URL relative to the web application root of this web application
-     * @return the resource identified by the relative URL, or null if it does not exist
-     */
-    @Override
-    public ResourceEntry getResource(String relativeURL) {
-        ResourceEntry data = null;
-
-        // check the request path prefix whether it matches with one of the prefixes in the prefix mapping; if yes,
-        // lookup the resource as follows:
-        // 1. look in the cache using the path of the request url as cache key
-        // 2. if not found: look in the jar file by mapping the resource to the correct jar file and retrieving it
-        //    from the "web" folder contained therein
-        // 3. if not found: proceed with the chain by calling chain.doFilter()
-        // TODO: (FIXME) data_cache.get(path) might return null some times even though path is in cache
-        if(isCached(relativeURL)) {
-            data = getFromCache(relativeURL);
-        } else {
-
-            try {
-                URL jarUrl = resolveResource(relativeURL);
-
-                if(jarUrl != null) {
-                    try {
-                        byte[] bytes = ByteStreams.toByteArray(jarUrl.openStream());
-
-                        data = new ResourceEntry(jarUrl,bytes,bytes.length,getMimeType(jarUrl));
-
-                        log.debug("retrieved resource {} (mime type {}, length {} bytes)", jarUrl.toString(), data.getContentType(),data.getLength());
-                    } catch (NullPointerException e) {
-                        // This happens if a directory is accessed in the jar-file.
-                        data = null;
-                    }
-                    putInCache(relativeURL,data);
-                } else {
-                    putInCache(relativeURL,null);
-
-                    log.debug("resource {} not found in any module",relativeURL);
-                }
-
-            } catch(IOException ex) {
-                log.debug("error while trying to retrieve resource {}: {}",relativeURL,ex.getMessage());
-            }
-        }
-        return data;
-
-    }
-
-    /**
-     * Return the file system URL of the resource identified by the relative HTTP URL passed as argument.
-     * he passed argument is relative to the web application root of this web application.
-     *
-     * @param relativeURL a URL relative to the web application root of this web application
-     * @return the file system URL of the resource, regardless whether it actually exists or not
-     */
-    @Override
-    public URL resolveResource(String relativeURL) {
-
-        // we take the first match from the resource map ...
-        for(String key : resourceMap.keySet()) {
-            if(relativeURL.startsWith(key)) {
-
-                // the name of the resource inside the jar file
-                String entryPath    = relativeURL.substring(key.length());
-                // map "/" to /index.html
-                if(entryPath.endsWith("/") || entryPath.equals("")) {
-                    entryPath += "index.html";
-                }
-
-                // the base URL of the jar file in the file system
-                String jarUrlBase   = resourceMap.get(key);
-
-                // the JAR URL of the resource inside the jar file
-                String jarUrlEntry;
-
-                if(jarUrlBase.endsWith(".jar")) {
-                    jarUrlEntry = "jar:" + jarUrlBase + "!/web" + ( entryPath.startsWith("/") ? entryPath : "/" + entryPath);
-                } else {
-                    jarUrlEntry = jarUrlBase + (jarUrlBase.endsWith("/")?"":"/") + "web" + ( entryPath.startsWith("/") ? entryPath : "/" + entryPath);
-                }
-
-
-                try {
-                    return new URL(jarUrlEntry);
-
-                } catch(IOException ex) {
-                    log.debug("error while trying to retrieve resource {}: {}",jarUrlEntry,ex.getMessage());
-
-                }
-            }
-        }
-        return null;
-    }
-
-
-
-
-
-    private boolean isCacheEnabled() {
-        return configurationService.getBooleanConfiguration("resources.servercache.enabled", false);
-    }
-
-
-    private boolean isCached(String key) {
-        return isCacheEnabled() && resourceCache.isKeyInCache(key) && resourceCache.get(key) != null;
-    }
-
-    private ResourceEntry getFromCache(String key) {
-        if (isCacheEnabled())
-            return (ResourceEntry) resourceCache.get(key).getObjectValue();
-        else
-            return null;
-    }
-
-    // Store in the cache
-    private void putInCache(String key, ResourceEntry data) {
-        if(isCacheEnabled()) {
-            resourceCache.put(new Element(key,data));
-        }
-    }
-
-
-    private String getMimeType(URL resource) {
-
-        @SuppressWarnings("unchecked")
-        Collection<MimeType> types = mimeUtil.getMimeTypes(resource);
-
-        if(types.size() > 0) {
-            MimeType t = types.iterator().next();
-            return t.toString();
-        } else
-            return null;
-
-    }
-
-
-}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/modules/MarmottaResourceServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/modules/MarmottaResourceServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/modules/MarmottaResourceServiceImpl.java
new file mode 100644
index 0000000..53b709e
--- /dev/null
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/modules/MarmottaResourceServiceImpl.java
@@ -0,0 +1,252 @@
+/**
+ * Copyright (C) 2013 Salzburg Research.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.marmotta.platform.core.services.modules;
+
+import com.google.common.io.ByteStreams;
+import eu.medsea.mimeutil.MimeType;
+import eu.medsea.mimeutil.MimeUtil2;
+import org.apache.marmotta.platform.core.api.config.ConfigurationService;
+import org.apache.marmotta.platform.core.api.modules.MarmottaResourceService;
+import org.apache.marmotta.platform.core.api.modules.ModuleService;
+import org.apache.marmotta.platform.core.api.modules.ResourceEntry;
+import org.apache.marmotta.platform.core.events.SystemStartupEvent;
+import org.apache.marmotta.platform.core.model.module.ModuleConfiguration;
+import org.apache.marmotta.platform.core.qualifiers.cache.MarmottaCache;
+import net.sf.ehcache.Ehcache;
+import net.sf.ehcache.Element;
+import org.slf4j.Logger;
+
+import javax.annotation.PostConstruct;
+import javax.enterprise.context.ApplicationScoped;
+import javax.enterprise.event.Observes;
+import javax.inject.Inject;
+
+import java.io.IOException;
+import java.net.URL;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.Map;
+
+/**
+ * A service for resolving and accessing resources contained in the Apache Marmotta modules. The resource service takes care
+ * of retrieving, caching and refreshing resources from the appropriate locations.
+ * <p/>
+ * Note that the resource service is not to be confused with the RDF resources maintained by the server. It is
+ * purely meant to retrieve static non-Java resources contained in the modules and web application.
+ *
+ * User: sschaffe
+ */
+@ApplicationScoped
+public class MarmottaResourceServiceImpl implements MarmottaResourceService {
+
+    @Inject
+    private Logger log;
+
+    @Inject
+    private ConfigurationService configurationService;
+
+
+    @Inject
+    private ModuleService moduleService;
+
+
+    @Inject @MarmottaCache("resource-cache")
+    private Ehcache resourceCache;
+
+    /**
+     * Used for detecting the mime type of resources contained in KiWi modules
+     */
+    private MimeUtil2 mimeUtil;
+
+
+    private Map<String,String> resourceMap;
+
+
+    @PostConstruct
+    public void initialise() {
+        // find all kiwi-module.properties and check whether they contain a baseurl property to map module web
+        // resources to a certain path prefix; if yes, store the prefix and jar URL in the map for lookup and
+        // resource resolving by the filter
+        this.resourceMap = new HashMap<String, String>();
+
+
+        for(String module : moduleService.listModules()) {
+            ModuleConfiguration config = moduleService.getModuleConfiguration(module);
+
+            if(config.getConfiguration().containsKey("baseurl")) {
+                String path = config.getConfiguration().getString("baseurl");
+                resourceMap.put(path.startsWith("/")?path:"/"+path,moduleService.getModuleJar(module).toString());
+            }
+        }
+
+
+
+        // detect the mime type of resources
+        this.mimeUtil = new MimeUtil2();
+        this.mimeUtil.registerMimeDetector("eu.medsea.mimeutil.detector.ExtensionMimeDetector");
+    }
+
+
+    /**
+     * Makes sure the service is initialised on system startup
+     *
+     * @param event
+     */
+    public void systemStartup(@Observes SystemStartupEvent event) {
+
+    }
+
+
+    /**
+     * Return the resource identified by the relative URL passed as argument. The passed argument is relative
+     * to the web application root of this web application.
+     *
+     * @param relativeURL a URL relative to the web application root of this web application
+     * @return the resource identified by the relative URL, or null if it does not exist
+     */
+    @Override
+    public ResourceEntry getResource(String relativeURL) {
+        ResourceEntry data = null;
+
+        // check the request path prefix whether it matches with one of the prefixes in the prefix mapping; if yes,
+        // lookup the resource as follows:
+        // 1. look in the cache using the path of the request url as cache key
+        // 2. if not found: look in the jar file by mapping the resource to the correct jar file and retrieving it
+        //    from the "web" folder contained therein
+        // 3. if not found: proceed with the chain by calling chain.doFilter()
+        // TODO: (FIXME) data_cache.get(path) might return null some times even though path is in cache
+        if(isCached(relativeURL)) {
+            data = getFromCache(relativeURL);
+        } else {
+
+            try {
+                URL jarUrl = resolveResource(relativeURL);
+
+                if(jarUrl != null) {
+                    try {
+                        byte[] bytes = ByteStreams.toByteArray(jarUrl.openStream());
+
+                        data = new ResourceEntry(jarUrl,bytes,bytes.length,getMimeType(jarUrl));
+
+                        log.debug("retrieved resource {} (mime type {}, length {} bytes)", jarUrl.toString(), data.getContentType(),data.getLength());
+                    } catch (NullPointerException e) {
+                        // This happens if a directory is accessed in the jar-file.
+                        data = null;
+                    }
+                    putInCache(relativeURL,data);
+                } else {
+                    putInCache(relativeURL,null);
+
+                    log.debug("resource {} not found in any module",relativeURL);
+                }
+
+            } catch(IOException ex) {
+                log.debug("error while trying to retrieve resource {}: {}",relativeURL,ex.getMessage());
+            }
+        }
+        return data;
+
+    }
+
+    /**
+     * Return the file system URL of the resource identified by the relative HTTP URL passed as argument.
+     * he passed argument is relative to the web application root of this web application.
+     *
+     * @param relativeURL a URL relative to the web application root of this web application
+     * @return the file system URL of the resource, regardless whether it actually exists or not
+     */
+    @Override
+    public URL resolveResource(String relativeURL) {
+
+        // we take the first match from the resource map ...
+        for(String key : resourceMap.keySet()) {
+            if(relativeURL.startsWith(key)) {
+
+                // the name of the resource inside the jar file
+                String entryPath    = relativeURL.substring(key.length());
+                // map "/" to /index.html
+                if(entryPath.endsWith("/") || entryPath.equals("")) {
+                    entryPath += "index.html";
+                }
+
+                // the base URL of the jar file in the file system
+                String jarUrlBase   = resourceMap.get(key);
+
+                // the JAR URL of the resource inside the jar file
+                String jarUrlEntry;
+
+                if(jarUrlBase.endsWith(".jar")) {
+                    jarUrlEntry = "jar:" + jarUrlBase + "!/web" + ( entryPath.startsWith("/") ? entryPath : "/" + entryPath);
+                } else {
+                    jarUrlEntry = jarUrlBase + (jarUrlBase.endsWith("/")?"":"/") + "web" + ( entryPath.startsWith("/") ? entryPath : "/" + entryPath);
+                }
+
+
+                try {
+                    return new URL(jarUrlEntry);
+
+                } catch(IOException ex) {
+                    log.debug("error while trying to retrieve resource {}: {}",jarUrlEntry,ex.getMessage());
+
+                }
+            }
+        }
+        return null;
+    }
+
+
+
+
+
+    private boolean isCacheEnabled() {
+        return configurationService.getBooleanConfiguration("resources.servercache.enabled", false);
+    }
+
+
+    private boolean isCached(String key) {
+        return isCacheEnabled() && resourceCache.isKeyInCache(key) && resourceCache.get(key) != null;
+    }
+
+    private ResourceEntry getFromCache(String key) {
+        if (isCacheEnabled())
+            return (ResourceEntry) resourceCache.get(key).getObjectValue();
+        else
+            return null;
+    }
+
+    // Store in the cache
+    private void putInCache(String key, ResourceEntry data) {
+        if(isCacheEnabled()) {
+            resourceCache.put(new Element(key,data));
+        }
+    }
+
+
+    private String getMimeType(URL resource) {
+
+        @SuppressWarnings("unchecked")
+        Collection<MimeType> types = mimeUtil.getMimeTypes(resource);
+
+        if(types.size() > 0) {
+            MimeType t = types.iterator().next();
+            return t.toString();
+        } else
+            return null;
+
+    }
+
+
+}

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/triplestore/ContextServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/triplestore/ContextServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/triplestore/ContextServiceImpl.java
index d4f4b8e..0505f12 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/triplestore/ContextServiceImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/triplestore/ContextServiceImpl.java
@@ -23,7 +23,7 @@ import org.apache.marmotta.platform.core.api.importer.ImportService;
 import org.apache.marmotta.platform.core.api.triplestore.ContextService;
 import org.apache.marmotta.platform.core.api.triplestore.SesameService;
 import org.apache.marmotta.platform.core.api.user.UserService;
-import org.apache.marmotta.platform.core.exception.io.LMFImportException;
+import org.apache.marmotta.platform.core.exception.io.MarmottaImportException;
 import org.apache.marmotta.platform.core.qualifiers.kspace.*;
 import org.apache.commons.lang.StringUtils;
 import org.openrdf.model.Resource;
@@ -324,7 +324,7 @@ public class ContextServiceImpl implements ContextService {
                 URI ctx = conn.getValueFactory().createURI(context);
                 int imported = importService.importData(is, format, userService.getCurrentUser(), ctx);
                 return imported > 0;
-            } catch (LMFImportException e) {
+            } catch (MarmottaImportException e) {
                 log.error(e.getMessage(), e);
             } finally {
                 conn.commit();

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/user/UserServiceImpl.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/user/UserServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/user/UserServiceImpl.java
index e4e87e4..9f0c89c 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/user/UserServiceImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/user/UserServiceImpl.java
@@ -27,7 +27,7 @@ import org.apache.marmotta.platform.core.api.user.UserService;
 import org.apache.marmotta.platform.core.events.SystemRestartedEvent;
 import org.apache.marmotta.platform.core.events.SystemRestartingEvent;
 import org.apache.marmotta.platform.core.exception.UserExistsException;
-import org.apache.marmotta.platform.core.model.user.KiWiUser;
+import org.apache.marmotta.platform.core.model.user.MarmottaUser;
 import org.apache.marmotta.platform.core.qualifiers.user.AdminUser;
 import org.apache.marmotta.platform.core.qualifiers.user.AnonymousUser;
 import org.apache.marmotta.platform.core.qualifiers.user.CurrentUser;
@@ -275,7 +275,7 @@ public class UserServiceImpl implements UserService {
                     log.info("creating user with webId: {} ", webId.stringValue());
 
                     if (!login.equals(ANONYMOUS_LOGIN) && !login.equals(ADMIN_LOGIN)) {
-                        KiWiUser u = FacadingFactory.createFacading(conn).createFacade(webId, KiWiUser.class);
+                        MarmottaUser u = FacadingFactory.createFacading(conn).createFacade(webId, MarmottaUser.class);
                         u.setFirstName(firstName);
                         u.setLastName(lastName);
                         u.setNick(login);

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupFilter.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupFilter.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupFilter.java
index 580c6a9..c7ab7a7 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupFilter.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupFilter.java
@@ -16,7 +16,7 @@
 package org.apache.marmotta.platform.core.servlet;
 
 import org.apache.marmotta.platform.core.api.config.ConfigurationService;
-import org.apache.marmotta.platform.core.startup.LMFStartupService;
+import org.apache.marmotta.platform.core.startup.MarmottaStartupService;
 import org.slf4j.Logger;
 
 import javax.inject.Inject;
@@ -47,7 +47,7 @@ public class KiWiPreStartupFilter implements Filter {
     private Logger log;
 
     @Inject
-    private LMFStartupService startupService;
+    private MarmottaStartupService startupService;
 
     @Inject
     private ConfigurationService configurationService;

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupListener.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupListener.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupListener.java
index f8da8a5..9036018 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupListener.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiPreStartupListener.java
@@ -15,8 +15,8 @@
  */
 package org.apache.marmotta.platform.core.servlet;
 
-import org.apache.marmotta.platform.core.startup.LMFStartupService;
-import org.apache.marmotta.platform.core.util.KiWiContext;
+import org.apache.marmotta.platform.core.startup.MarmottaStartupService;
+import org.apache.marmotta.platform.core.util.CDIContext;
 
 import javax.servlet.ServletContextEvent;
 import javax.servlet.ServletContextListener;
@@ -27,7 +27,7 @@ import javax.servlet.ServletContextListener;
  */
 public class KiWiPreStartupListener implements ServletContextListener {
 
-    private LMFStartupService lmfStartupService;
+    private MarmottaStartupService lmfStartupService;
 
     /**
      * * Notification that the web application initialization
@@ -40,7 +40,7 @@ public class KiWiPreStartupListener implements ServletContextListener {
     public void contextInitialized(ServletContextEvent sce) {
 
         if(lmfStartupService == null) {
-            lmfStartupService = KiWiContext.getInstance(LMFStartupService.class);
+            lmfStartupService = CDIContext.getInstance(MarmottaStartupService.class);
         }
 
         lmfStartupService.startupConfiguration(null,null,sce.getServletContext());

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiResourceFilter.java
----------------------------------------------------------------------
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiResourceFilter.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiResourceFilter.java
index a3d25fe..1736f53 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiResourceFilter.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/servlet/KiWiResourceFilter.java
@@ -16,7 +16,7 @@
 package org.apache.marmotta.platform.core.servlet;
 
 import org.apache.marmotta.platform.core.api.config.ConfigurationService;
-import org.apache.marmotta.platform.core.api.modules.LMFHttpFilter;
+import org.apache.marmotta.platform.core.api.modules.MarmottaHttpFilter;
 import org.apache.marmotta.platform.core.api.modules.ModuleService;
 import org.slf4j.Logger;
 
@@ -60,9 +60,9 @@ public class KiWiResourceFilter implements Filter {
     private ModuleService moduleService;
 
     @Inject @Any
-    private Instance<LMFHttpFilter> filters;
+    private Instance<MarmottaHttpFilter> filters;
 
-    private List<LMFHttpFilter> filterList;
+    private List<MarmottaHttpFilter> filterList;
 
     /**
      * Called by the web container to indicate to a filter that it is being placed into
@@ -80,9 +80,9 @@ public class KiWiResourceFilter implements Filter {
 
 
         // initialise filter chain and sort it according to priority
-        this.filterList  = new ArrayList<LMFHttpFilter>();
+        this.filterList  = new ArrayList<MarmottaHttpFilter>();
 
-        for(LMFHttpFilter filter : filters) {
+        for(MarmottaHttpFilter filter : filters) {
             try {
                 filter.init(filterConfig);
                 filterList.add(filter);
@@ -146,7 +146,7 @@ public class KiWiResourceFilter implements Filter {
      */
     @Override
     public void destroy() {
-        for(LMFHttpFilter filter : filterList) {
+        for(MarmottaHttpFilter filter : filterList) {
             filter.destroy();
         }
     }
@@ -157,7 +157,7 @@ public class KiWiResourceFilter implements Filter {
      */
     private class LMFFilterChain implements FilterChain {
 
-        private Iterator<LMFHttpFilter> filters;
+        private Iterator<MarmottaHttpFilter> filters;
 
         private String path;
 
@@ -173,7 +173,7 @@ public class KiWiResourceFilter implements Filter {
         @Override
         public void doFilter(ServletRequest request, ServletResponse response) throws IOException, ServletException {
             if(filters.hasNext()) {
-                LMFHttpFilter filter = filters.next();
+                MarmottaHttpFilter filter = filters.next();
 
                 if(path.matches(filter.getPattern())) {
                     filter.doFilter(request,response,this);
@@ -188,7 +188,7 @@ public class KiWiResourceFilter implements Filter {
 
 
 
-    private static class FilterComparator implements Comparator<LMFHttpFilter>, Serializable {
+    private static class FilterComparator implements Comparator<MarmottaHttpFilter>, Serializable {
 
         private static final long serialVersionUID = -7264645592168345092L;
 
@@ -207,7 +207,7 @@ public class KiWiResourceFilter implements Filter {
          *                            being compared by this comparator.
          */
         @Override
-        public int compare(LMFHttpFilter o1, LMFHttpFilter o2) {
+        public int compare(MarmottaHttpFilter o1, MarmottaHttpFilter o2) {
             if(o1.getPriority() < o2.getPriority())
                 return -1;
             else if(o1.getPriority() > o2.getPriority()) return 1;
diff --git a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/config/ConfigurationServiceImpl.java b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/config/ConfigurationServiceImpl.java
index e2bd89f..51161be 100644
--- a/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/config/ConfigurationServiceImpl.java
+++ b/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/config/ConfigurationServiceImpl.java
@@ -72,7 +72,7 @@ public class ConfigurationServiceImpl implements ConfigurationService {
     private CompositeConfiguration config;
 
     /**
      * The backend for storing configuration values, usually ${kiwi.home}/system-config.properties
      */
     private Configuration saveConfiguration;
 
@@ -105,7 +105,7 @@ public class ConfigurationServiceImpl implements ConfigurationService {
     }
 
     /**
      * Initialise the ConfigurationService. Takes the kiwi.home system property from the servlet
      * init parameters
      * (web.xml) as bootstrap home. In case a system-config.properties file is found in this
      * directory, the
@@ -172,7 +172,7 @@ public class ConfigurationServiceImpl implements ConfigurationService {
                 }
                 saveConfiguration = new PropertiesConfiguration(f);
             } else {
-                log.error("error while initialising configuration: no kiwi.home property given; creating memory-only configuration");
+                log.error("error while initialising configuration: no marmotta.home property given; creating memory-only configuration");
                 saveConfiguration = new MapConfiguration(new HashMap<String, Object>());
 
             }
@@ -231,7 +231,7 @@ public class ConfigurationServiceImpl implements ConfigurationService {
         // setup KiWi home - if it is given as system property, the bootstrap configuration is
         // overwritten
         if (getLMFHome() != null) {
-            config.setProperty("kiwi.home", getLMFHome());
+            config.setProperty("marmotta.home", getLMFHome());
             config.setProperty("solr.home", getLMFHome() + File.separator + "solr");
         }
 
@@ -880,7 +880,7 @@ public class ConfigurationServiceImpl implements ConfigurationService {
 
     @Override
     public String getWorkDir() {
-        final String value = getStringConfiguration("kiwi.home");
+        final String value = getStringConfiguration("marmotta.home");
         return value != null ? value : new File(System.getProperty("java.io.tmpdir", "/tmp"), "lmf").getAbsolutePath();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-marmotta/blob/9ab0f4e1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/services/content/ContentServiceImpl.java
----------------------------------------------------------------------
@@ -72,7 +72,7 @@ public class ConfigurationServiceImpl implements ConfigurationService {
 
     /**
-     * The backend for storing configuration values, usually ${kiwi.home}/system-config.properties
+     * The backend for storing configuration values, usually ${marmotta.home}/system-config.properties
      */
     private Configuration saveConfiguration;
@@ -105,7 +105,7 @@ public class ConfigurationServiceImpl implements ConfigurationService {
 
     /**
-     * Initialise the ConfigurationService. Takes the kiwi.home system property from the servlet
+     * Initialise the ConfigurationService. Takes the marmotta.home system property from the servlet
      * init parameters
      * (web.xml) as bootstrap home. In case a system-config.properties file is found in this